@@ -183,7 +183,7 @@ def Parse(tree: Element) -> List[Annotation]:
         else:
             annotation.text = MakeSureStr(text.text)
 
-        if len(each.find("segment").find("movingRegion")) == 0:  # type: ignore
+        if each.find("segment").find("movingRegion") == None:  # type: ignore
             # 学习 annotationlib
             # https://github.com/isaackd/annotationlib/blob/0818bddadade8dd1d13f3006e34a5837a539567f/src/parser/index.js#L117
             # 跳过没有内容的 Annotation
@@ -208,9 +208,13 @@ def Parse(tree: Element) -> List[Annotation]:
                 # 我选择相信别人的经验
                 # 毕竟我也没咋看过 Youtube
                 if Flags.verbose:
-                    Stderr(_("{} highlightText 没有时间, 跳过").format(annotation.id))
+                    Stderr(_("{} 没有时间, 跳过").format(annotation.id))
                 return None
 
+        if annotation.style == "highlightText":
+            Start = "9:00:00.00"
+            End = "9:00:00.00"
+
         if len(Segment) != 0:
             t1 = MakeSureStr(Segment[0].get("t"))
             t2 = MakeSureStr(Segment[1].get("t"))
